<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package culinary
 */
 
 
 /**
 * Default menu item if no menu is assigned in bottom header
 * Called in header.php
 */
if ( ! function_exists( 'culinary_demo_main_menu_nav' ) ) :
	function culinary_demo_main_menu_nav() { ?>

		<ul id="menu-primary" class="menu vertical medium-horizontal left_top_nav dropdown" data-responsive-menu="accordion medium-dropdown" role="menubar">
			<li class="menu-item">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php _e('Home','culinary') ?></a>
			</li>
			<li class="menu-item">
				<a href="#"><?php _e('Blog','culinary') ?></a>
			</li>
			<li class="menu-item has-dropdown">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php _e('Dropdown','culinary') ?></a>
				<ul class="dropdown vertical menu submenu is-dropdown-submenu first-sub">
					<li class="menu-item is-submenu-item is-dropdown-submenu-item"><a href="#"><?php _e('First Level','culinary') ?></a></li>
					<li class="menu-item is-submenu-item is-dropdown-submenu-item"><a href="#"><?php _e('Second Level','culinary') ?></a></li>
					<li class="menu-item is-submenu-item is-dropdown-submenu-item"><a href="#"><?php _e('Third Level','culinary') ?></a></li>
				</ul>
			</li>
			<li class="menu-item">
				<a href="#"><?php _e('Example Menu','culinary') ?></a>
			</li>
		</ul>

	<?php }
endif;

/**
 * Default menu item if no menu is assigned in top header menu
 * Called in header.php
 */
if ( ! function_exists( 'culinary_demo_top_header_nav' ) ) :
	function culinary_demo_top_header_nav() { ?>

		<ul class="menu medium-horizontal right_top_nav">
			<li class="menu-item">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php _e('Home','culinary') ?></a>
			</li>
			<li class="menu-item">
				<a href="#"><?php _e('Blog','culinary') ?></a>
			</li>
			<li class="menu-item">
				<a href="#"><?php _e('Example Menu','culinary') ?></a>
			</li>
		</ul>

	<?php }
endif;

/**
 * Default menu item if no menu is assigned in social header & footer menus
 * Called in header.php and footer.php
 */
if ( ! function_exists( 'culinary_demo_social_menu_nav' ) ) :
	function culinary_demo_social_menu_nav() { ?>
		<ul>
			<li class="menu-item menu-item-type-custom menu-item-object-custom menu-item-12">
				<a href="<?php echo esc_url( __('http://facebook.com', 'culinary'));?>"><span class="screen-reader-text"><?php _e('Facebook','culinary') ?></span></a>
			</li>
			<li class="menu-item menu-item-type-custom menu-item-object-custom menu-item-12">
				<a href="<?php echo esc_url( __('http://twitter.com', 'culinary'));?>"><span class="screen-reader-text"><?php _e('Twitter','culinary') ?></span></a>
			</li>
			<li class="menu-item menu-item-type-custom menu-item-object-custom menu-item-12">
				<a href="<?php echo esc_url( __('http://pinterest.com', 'culinary'));?>"><span class="screen-reader-text"><?php _e('Pinterest','culinary') ?></span></a>
			</li>
		</ul>

	<?php }
endif;


/**
 * Template for comments and pingbacks.
 */
if ( ! function_exists( 'culinary_comments' ) ) :
    function culinary_comments( $comment, $args, $depth ) {

        switch ( $comment->comment_type ) :
            case '' :
        ?>

        <li <?php comment_class('clearfix'); ?> id="li-comment-<?php comment_ID() ?>">

            <div id="comment-<?php comment_ID(); ?>" class=" clearfix">    

	            <?php echo get_avatar($comment,$size='60',$default='mm' ); ?>                                      
                <div class="comment-content">

                    <div class="comment-text">                      
                        
                        <p class='comment-meta-header'>

                            <cite class="fn"><?php echo get_comment_author_link() ?></cite>                     
                            <span class="comment-meta commentmetadata"><?php comment_date(get_option('date_format')); ?></span>
                            <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>

                        </p><!-- .comment-meta-header -->
                        
                        <?php if ($comment->comment_approved == '0') : ?><p class="moderated"><?php _e('Your comment is awaiting moderation.','culinary'); ?></p><?php endif; ?>

                        <div class="comment_content">

                        <?php comment_text() ?>

                        </div><!-- .comment_content -->

                    </div><!-- .comment-text-->    

                </div><!-- .comment-content -->

            </div><!-- .comment-<?php comment_ID(); ?> -->
            
        <?php
            break;
            case 'pingback'  :
            case 'trackback' :
        ?>
            <li <?php comment_class('clearfix'); ?> id="li-comment-<?php comment_ID() ?>">
            <div id="comment-<?php comment_ID(); ?>" class="clearfix">
                    <?php echo "<div class='author'><em>" . __('Trackback:','culinary') . "</em> ".get_comment_author_link()."</div>"; ?>
                    <?php echo strip_tags(substr(get_comment_text(),0, 110)) . "..."; ?>
                    <?php comment_author_url_link('', '<small>', '</small>'); ?>
             </div>
            <?php
            break;
        endswitch;
    }
    endif;

if ( ! function_exists( 'culinary_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function culinary_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( esc_attr( get_the_time( 'U' ) ) !== esc_attr( get_the_modified_time( 'U' ) ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$byline = sprintf(
		esc_html_x( 'by %s', 'post author', 'culinary' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $time_string . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

if ( ! function_exists( 'culinary_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function culinary_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'culinary' ) );
		if ( $categories_list && culinary_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'culinary' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'culinary' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'culinary' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="left">';
		echo '<span class="comments-link">';
		/* translators: %s: post title */

		comments_popup_link( sprintf( wp_kses( __( ' <span class="screen-reader-text"> on %s</span>', 'culinary' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ), __( ' 1', 'culinary' ), __( ' %', 'culinary' ),"fa fa-comment" );
		echo '</span>';
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'culinary' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

if ( ! function_exists( 'culinary_categorized_blog' ) ) :
/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function culinary_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'culinary_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'culinary_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so culinary_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so culinary_categorized_blog should return false.
		return false;
	}
}
endif;


/**
 * Replaces ellipsis with Read More.
 *
 * @return bool
 */
function culinary_custom_more($more) {
    global $post;
    return '<a href='. esc_url( get_permalink($post->ID) ) . ' class="read-more">' . __( 'Read More', 'culinary' ) .'</a>';
}
add_filter('excerpt_more', 'culinary_custom_more', 1000);

/**
 * Flush out the transients used in culinary_categorized_blog.
 */
function culinary_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'culinary_categories' );
}
add_action( 'edit_category', 'culinary_category_transient_flusher' );
add_action( 'save_post',     'culinary_category_transient_flusher' );

if ( ! function_exists( 'culinary_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function culinary_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<span class="screen-reader-text"><?php _e( 'Posts navigation', 'culinary' ); ?></span>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'culinary' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'culinary' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'culinary_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function culinary_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation clearfix" role="navigation">
		<span class="screen-reader-text"><?php _e( 'Post navigation', 'culinary' ); ?></span>
		<div class="nav-links clearfix">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span>&nbsp;%title', 'Previous post link', 'culinary' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '%title&nbsp;<span class="meta-nav">&rarr;</span>', 'Next post link',     'culinary' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

/**
 * Display custom image header
 */
function culinary_display_background_header_image() {
  ?>
 	<style>
		.custom-header {
			background:url( '<?php echo esc_url( header_image() ) ?>' ) center bottom;
			-webkit-background-size: cover;
			-moz-background-size: cover;
			-o-background-size: cover;
			background-size: cover;
			height: 100%;
		}
	</style>
	<?php
}

/**
 * Register Google font.
 *
 */
function culinary_fonts() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';
	/* translators: If there are characters in your language that are not supported by Quattrocento, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Alegreya Sans font: on or off', 'culinary' ) ) {
		$fonts[] = 'Alegreya Sans:400,700';
	}

	/* translators: To add an additional character subset specific to your language, translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language. */
	$subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'culinary' );
	if ( 'cyrillic' == $subset ) {
		$subsets .= ',cyrillic,cyrillic-ext';
	} elseif ( 'greek' == $subset ) {
		$subsets .= ',greek,greek-ext';
	} elseif ( 'devanagari' == $subset ) {
		$subsets .= ',devanagari';
	} elseif ( 'vietnamese' == $subset ) {
		$subsets .= ',vietnamese';
	}
	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), '//fonts.googleapis.com/css' );
	}
	
	add_editor_style( $fonts_url );
	return $fonts_url;
}